Welcome to HADDOCK3 Documentation!
==================================

.. include:: ../README.md
   :start-after: .. start-description
   :end-before: .. end-description

You can now read through the **content** below.


Content
========

.. toctree::
   :maxdepth: 1

   intro
   INSTALL
   USAGE
   examples
   tutorials/index
   clients/haddock.clis
   modules/index
   testing/index
   contributing
   citing
   reference/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

